import type { AppRouteRecordRaw, AppRouteModule } from '@/router/types';

import { PAGE_NOT_FOUND_ROUTE, REDIRECT_ROUTE } from '@/router/routes/basic';
import { LAYOUT } from '@/router/constant';
import { mainOutRoutes } from './mainOut';
import { t } from '@/hooks/web/useI18n';

// import.meta.glob() 直接引入所有的模块 Vite 独有的功能
const modules = import.meta.glob('./modules/**/*.ts', { eager: true });
const routeModuleList: AppRouteModule[] = [];

// 加入到路由集合中
Object.keys(modules).forEach((key) => {
  const mod = (modules as Recordable)[key].default || {};
  const modList = Array.isArray(mod) ? [...mod] : [mod];
  routeModuleList.push(...modList);
});

export const asyncRoutes = [PAGE_NOT_FOUND_ROUTE, ...routeModuleList];

// 根路由
export const RootRoute: AppRouteRecordRaw = {
  path: '/',
  name: 'Root',
  redirect: '/homePage/index',
  meta: {
    title: 'Root',
  },
};

export const LoginRoute: AppRouteRecordRaw = {
  path: '/login',
  name: 'Login',
  component: () => import('@/views/sys/login/Login.vue'),
  meta: {
    title: t('routes.basic.login'),
  },
};
//10/24 10点19分 字典类型详情页路由
export const DictRoute: AppRouteRecordRaw = {
  path: '/dict',
  name: 'Dict',
  component: LAYOUT,
  meta: {
    title: '字典管理',
    icon: '',
    hidden: true,
    currentActiveMenu: '/system/dict',
  },
  children: [
    {
      path: 'type/data',
      name: 'Data',
      component: () => import('@/views/system/dict/data/index.vue'),
      meta: {
        title: '字典数据',
        icon: '',
      },
    },
  ],
};
export const mainBodyRoute: AppRouteRecordRaw = {
  path: '/mainBody',
  name: 'mainBody',
  component: LAYOUT,
  meta: {
    title: '主体管理',
    icon: '',
    hidden: true,
    currentActiveMenu: '/mainBody/index',
  },
  children: [
    {
      path: '/mainBody/details',
      name: 'details',
      component: () => import('@/views/mainBody/details/index.vue'),
      meta: {
        title: '主体管理详情',
        icon: '',
      },
    },
  ],
};

export const DataSourceRoute: AppRouteRecordRaw = {
  path: '/dataSourceManage',
  name: 'dataSourceManage',
  component: LAYOUT,
  meta: {
    title: '数据源',
    icon: '',
    hidden: true,
    currentActiveMenu: '/mainBody/index',
  },
  children: [
    {
      path: 'connect/CollectRecordModal',
      name: 'collectRecordModal',
      component: () => import('@/views/dataSourceManage/connect/CollectRecordModal.vue'),
      meta: {
        title: '日志详情',
        icon: '',
      },
    },
  ],
};

export const UserRoute: AppRouteRecordRaw = {
  path: '/user',
  name: 'User',
  component: LAYOUT,
  meta: {
    title: '用户管理',
    icon: '',
    hidden: true,
    currentActiveMenu: '/system/user',
  },
  children: [
    {
      path: 'AccountDetail',
      name: 'AccountDetail',
      component: () => import('@/views/system/user/AccountDetail.vue'),
      meta: {
        title: '用户详情',
        icon: '',
      },
    },
  ],
};

export const CommonFileRoute: AppRouteRecordRaw = {
  path: '/commonFile',
  name: 'commonFile',
  component: LAYOUT,
  meta: {
    title: '通用文件操作',
    icon: '',
    hidden: true,
    currentActiveMenu: '/commonFile',
  },
  children: [
    {
      path: 'fileDetail',
      name: 'fileDetail',
      component: () => import('@/views/commonFile/fileDetail.vue'),
      meta: {
        title: '文件详情',
        icon: '',
      },
    },
  ],
};

export const DataWarehousePlanningRoute: AppRouteRecordRaw = {
  path: '/dataWarehousePlanning',
  name: 'logicModel',
  component: LAYOUT,
  meta: {
    title: '编辑模型',
    icon: '',
    hidden: true,
    currentActiveMenu: '/dataWarehousePlanning',
  },
  children: [
    {
      path: 'logicalModel/detail',
      name: 'logicalModel',
      component: () => import('@/views/dataWarehousePlanning/logicalModel/modelDetail/index.vue'),
      meta: {
        title: '逻辑模型详情',
        icon: '',
      },
    },
    {
      path: 'logicalModel/entity-detail',
      name: 'logicalEntityModel',
      component: () =>
        import('@/views/dataWarehousePlanning/logicalModel/modelDetail/entityDetail/index.vue'),
      meta: {
        title: '实体详情',
        icon: '',
      },
    },
    {
      path: 'logicalModel/version-manage',
      name: 'logicalVersionModel',
      component: () => import('@/views/dataWarehousePlanning/logicalModel/versionManage/index.vue'),
      meta: {
        title: '转换记录',
        icon: '',
      },
    },
    {
      path: 'logicalModel/version-comparison',
      name: 'logicalVersionComparisonModel',
      component: () =>
        import(
          '@/views/dataWarehousePlanning/logicalModel/modelDetail/versionComparison/index.vue'
        ),
      meta: {
        title: '版本对比',
        icon: '',
      },
    },
    {
      path: 'logicalModel/ERchart',
      name: 'logicalChartModel',
      component: () => import('@/views/dataWarehousePlanning/logicalModel/modelDetail/ERchart/index.vue'),
      meta: {
        title: '实体关系图',
        icon: '',
      },
    },
  ],
};

/**物理模型*/
export const DataWarehousephysicalModelRoute: AppRouteRecordRaw = {
  path: '/dataWarehousePlanning',
  name: 'physicalModel',
  component: LAYOUT,
  meta: {
    title: '编辑模型',
    icon: '',
    hidden: true,
    currentActiveMenu: '/dataWarehousePlanning',
  },
  children: [
    {
      path: 'physicalModel/detail',
      name: 'physicalModelDetail',
      component: () => import('@/views/dataWarehousePlanning/physicalModel/modelDetail/index.vue'),
      meta: {
        title: '物理模型详情',
        icon: '',
      },
    },
  ],
};
export const ModelRoute: AppRouteRecordRaw = {
  path: '/metaModel',
  name: 'metaModel',
  component: LAYOUT,
  meta: {
    title: '编辑模型',
    icon: '',
    hidden: true,
    currentActiveMenu: '/metaModel',
  },
  children: [
    {
      path: 'physicsModel/index',
      name: 'physicsModelIndex',
      component: () => import('@/views/metaModel/physicsModel/index.vue'),
      meta: {
        title: '物理模型元模型',
        icon: '',
      },
    },
    {
      path: 'physicsModel/EditRowTable',
      name: 'physicsModel',
      component: () => import('@/views/metaModel/physicsModel/EditRowTable.vue'),
      meta: {
        title: '编辑物理模型',
        icon: '',
      },
    },
    {
      path: 'knowledgeModel/EditRowTable',
      name: 'knowledgeModel',
      component: () => import('@/views/metaModel/knowledgeModel/EditRowTable.vue'),
      meta: {
        title: '编辑知识库模型',
        icon: '',
      },
    },
    {
      path: 'standardModel/EditRowTable',
      name: 'standardModel',
      component: () => import('@/views/metaModel/standardModel/EditRowTable.vue'),
      meta: {
        title: '编辑数据标准模型',
        icon: '',
      },
    },
    {
      path: 'logicModels/EditRowTable',
      name: 'logicModels',
      component: () => import('@/views/metaModel/logicModel/EditRowTable.vue'),
      meta: {
        title: '编辑逻辑模型',
        icon: '',
      },
    },
  ],
};

/**基础标准*/
export const BasicStandardRoute: AppRouteRecordRaw = {
  path: '/dataStandards',
  name: 'dataStandards',
  component: LAYOUT,
  meta: {
    title: '基础标准',
    icon: '',
    hidden: true,
    currentActiveMenu: '/dataStandards',
  },
  children: [
    {
      path: 'basicStandards/detailStandard',
      name: 'detailStandard',
      component: () => import('@/views/dataStandards/basicStandards/detailStandard.vue'),
      meta: {
        title: '基础标准详情',
        icon: '',
      },
    },
    {
      path: 'basicStandards/editDetailStandard',
      name: 'editDetailStandard',
      component: () => import('@/views/dataStandards/basicStandards/editDetailStandard.vue'),
      meta: {
        title: '基础标准编辑',
        icon: '',
      },
    },
  ],
};


export const WorkSpaceRoute: AppRouteRecordRaw = {
  path: '/workspace',
  name: 'Workspace',
  component: LAYOUT,
  meta: {
    title: '工作区管理',
    icon: '',
    hidden: true,
    currentActiveMenu: '/system/workspace',
  },
  children: [
    {
      path: 'detail',
      name: 'Detail',
      component: () => import('@/views/system/workspace/detail.vue'),
      meta: {
        title: '工作区详情',
        icon: '',
      },
    },
  ],
};
// Basic routing without permission
// 没有权限要求的基本路由
export const basicRoutes = [
  LoginRoute,
  DictRoute,
  mainBodyRoute,
  UserRoute,
  WorkSpaceRoute,
  CommonFileRoute,
  ModelRoute,
  DataSourceRoute,
  BasicStandardRoute,
  // RootRoute,
  ...mainOutRoutes,
  REDIRECT_ROUTE,
  DataWarehousePlanningRoute,
  DataWarehousephysicalModelRoute,
  PAGE_NOT_FOUND_ROUTE,
];
